Coverage report

# Coverage report: 98%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 335 | 7 | 1 | 98%
wagtailsharing/__init__.py | 0 | 0 | 0 | 100%
wagtailsharing/helpers.py | 13 | 1 | 0 | 92%
wagtailsharing/migrations/0001_initial.py | 6 | 0 | 0 | 100%
wagtailsharing/migrations/__init__.py | 0 | 0 | 0 | 100%
wagtailsharing/models.py | 29 | 3 | 0 | 90%
wagtailsharing/tests/__init__.py | 0 | 0 | 0 | 100%
wagtailsharing/tests/helpers.py | 6 | 0 | 0 | 100%
wagtailsharing/tests/test_helpers.py | 26 | 0 | 0 | 100%
wagtailsharing/tests/test_models.py | 50 | 0 | 0 | 100%
wagtailsharing/tests/test_urls.py | 23 | 0 | 1 | 100%
wagtailsharing/tests/test_views.py | 104 | 0 | 0 | 100%
wagtailsharing/urls.py | 5 | 0 | 0 | 100%
wagtailsharing/views.py | 54 | 0 | 0 | 100%
wagtailsharing/wagtail_hooks.py | 19 | 3 | 0 | 84%

No items found using the specified filter.